/* 
   guile_wrapper.c: higher level wrapper to guile functions
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2, or (at
   your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */


#include <stdio.h>
#include <libguile.h>
#include "guile-wrapper.h"

SCM __gh_standard_handler(void *data, SCM tag, SCM throw_args)
{
  printf ("\n~qp~_~qp~_~qp~_~qp~_~qp~_~qp~");
  printf ("\n~qp~ FreeHoo Exception!! ~qp~");
  printf ("\n~qp~_~qp~_~qp~_~qp~_~qp~_~qp~");
  printf ("\n(C exception handler dump)");
  printf ("\ntag        : ");
  fflush (stdout);
  scm_display (tag, scm_current_output_port ());
  printf ("\nthrow args : ");
  fflush (stdout);
  scm_display (throw_args, scm_current_output_port ());
  printf ("\ndata       : [%s]\n", (char *) data);
  fflush (stdout);
  scm_backtrace ();
  fflush (stdout);
  scm_newline (scm_current_output_port ());
  return SCM_UNSPECIFIED;
}
